| Title: | Publish Packages and Other Resources to AnVIL Workspaces |
|---|---|
| Description: | Use this package to create or update AnVIL workspaces from resources such as R / Bioconductor packages. The metadata about the package (e.g., select information from the package DESCRIPTION file and from vignette YAML headings) are used to populate the 'DASHBOARD'. Vignettes are translated to python notebooks ready for evaluation in AnVIL. |
| Authors: | Marcel Ramos [aut, cre] (ORCID: <https://orcid.org/0000-0002-3242-0582>), Martin Morgan [aut] (ORCID: <https://orcid.org/0000-0002-5874-8148>), Kayla Interdonato [aut], Vincent Carey [ctb] (ORCID: <https://orcid.org/0000-0003-4046-0063>), NHGRI [fnd] (GrantNo.: U24HG010263) |
| Maintainer: | Marcel Ramos <[email protected]> |
| License: | Artistic-2.0 |
| Version: | 1.23.5 |
| Built: | 2026-05-30 09:43:53 UTC |
| Source: | https://github.com/bioc/AnVILPublish |
add_access() adds the Bioconductor_User group to a
workspace with READER permissions. Users gain access to
the workspace (and others) by being added to the
Bioconductor_User group.
add_access(namespace, name, dry.run = FALSE)add_access(namespace, name, dry.run = FALSE)
namespace |
character(1) namespace (billing account) under which the workspace belongs. |
name |
character(1) name of the workspace to add access credentials. |
dry.run |
|
add_access() returns TRUE, invisibly.
add_access("landmarkanvil2", "Bioconductor-Package-AnVILHCAR", TRUE)add_access("landmarkanvil2", "Bioconductor-Package-AnVILHCAR", TRUE)
as_notebook() renders Rmarkdown (.Rmd) or Quarto
(.qmd) vignettes as Juptyer (.ipynb) notebooks. The
vignettes and notebooks are updated in an AnVIL workspace.
as_notebook( rmd_paths, namespace, name, update = FALSE, type = c("ipynb", "rmd", "both"), quarto = c("render", "convert"), dry.run = FALSE )as_notebook( rmd_paths, namespace, name, update = FALSE, type = c("ipynb", "rmd", "both"), quarto = c("render", "convert"), dry.run = FALSE )
rmd_paths |
|
namespace |
|
name |
|
update |
|
type |
|
quarto |
|
dry.run |
|
See the vignette
"Publishing R / Bioconductor Packages To AnVIL Workspaces" for
details on the conversion process; best results are obtained
when the quarto command line interface (CLI) is available.
as_notebook() returns the paths to the local
(if update = FALSE or dry.run = TRUE) or the
workspace notebooks.
exampleRmd <- system.file("extdata", "example.Rmd", package = "AnVILPublish") as_notebook( exampleRmd, "landmarkanvil2", "Bioconductor-Package-AnVILHCAR", dry.run = TRUE )exampleRmd <- system.file("extdata", "example.Rmd", package = "AnVILPublish") as_notebook( exampleRmd, "landmarkanvil2", "Bioconductor-Package-AnVILHCAR", dry.run = TRUE )
as_workspace() renders a package source tree (e.g., from a
git checkout) as an AnVIL workspace.
as_workspace( path, namespace, name = NULL, create = FALSE, update = FALSE, use_readme = FALSE, type = c("ipynb", "rmd", "both"), quarto = c("render", "convert"), dry.run = FALSE )as_workspace( path, namespace, name = NULL, create = FALSE, update = FALSE, use_readme = FALSE, type = c("ipynb", "rmd", "both"), quarto = c("render", "convert"), dry.run = FALSE )
path |
|
namespace |
|
name |
|
create |
|
update |
|
use_readme |
|
type |
|
quarto |
|
dry.run |
|
Information from the DESCRIPTION file and Rmd YAML are
used to populate the 'DASHBOARD' tab. See ?as_notebook() for
details on how vignettes are processed to notebooks.
as_workspace() returns the URL of the updated workspace,
invisibly.
as_workspace( path = "../AnVILPublish", namespace = "landmarkanvil2", name = "Bioconductor-Package-AnVILHCAR", dry.run = TRUE )as_workspace( path = "../AnVILPublish", namespace = "landmarkanvil2", name = "Bioconductor-Package-AnVILHCAR", dry.run = TRUE )
Call the Terra() API to create a new AnVIL workspace. This is
a helper function for as_workspace(), but can be used directly if you
want to create a workspace without populating it with content from an R
package. This is typically used by developers who want to create a
workspace and then run other functions to populate it with content, e.g.,
importing data into the workspace.
create_workspace(namespace, name)create_workspace(namespace, name)
namespace |
|
name |
|
create_workspace() returns TRUE invisibly if the workspace was
created successfully; otherwise, an error is raised.
create_workspace("my-namespace", "my-workspace")create_workspace("my-namespace", "my-workspace")